## Introduction
jUDDI (pronounced "Judy") is an open source Java implementation of [OASIS](https://www.oasis-open.org) the [Universal Description, Discovery, and Integration (UDDI)](https://www.oasis-open.org/standards#uddiv3.0.2) specification for (Web) Services. The jUDDI project includes [Scout](http://projects.apache.org/projects/scout.html). Scout is an implementation of the [JSR 93 - JavaTM API for XML Registries 1.0 (JAXR)](https://jcp.org/en/jsr/detail?id=93).

## Features
 - Open Source
 - Platform Independent
 - Use with any relational database that supports ANSI standard SQL (MySQL, Oracle, DB2, Sybase, Derby etc.)
 - Deployable on any Java application server that supports the Servlet 2.3 specification
 - jUDDI registry supports a clustered deployment configuration.
 - Easy integration with existing authentication systems
 - Supports InVM embeddable mode

## jUDDIv3 Services

 - UDDI Specification version [3.0.2](http://uddi.org/pubs/uddi-v3.0.2-20041019.htm) compliant
 - UDDI Specification version [2.0.4](http://uddi.org/pubs/ProgrammersAPI-V2.04-Published-20020719.htm) interoperability services (BETA)
 - JDK 1.6 Recommended
 - Built on [JAXB](https://jcp.org/en/jsr/detail?id=222) and [JAX-WS](https://jcp.org/en/jsr/detail?id=224) standardized interfaces, tested on [Apache CXF](http://cxf.apache.org)
 - Built on JPA standardized interfaces, tested with [Apache OpenJPA](http://openjpa.apache.org/) and [Hibernate](http://hibernate.org/)
 - Pre-configured bundle deployed to [Apache Tomcat](http://tomcat.apache.org/)
 - Full featured user interface (based on [Bootstrap](http://getbootstrap.com/2.3.2/))
 - Pre-configured portal bundle download (up to v3.1.5)
 - User, Administrative and Developer Documentation
 - Includes extensive predefined tModels, such as [Quality of Service Metrics](https://www.oasis-open.org/committees/download.php/6227/uddi-spec-tc-tn-QoS-metrics-20040224.doc)

## UDDIv3 API Client Libraries

 - Java using JRE 1.6
 - .NET using Microsoft.NET Framework v3.5 (since jUDDI 3.2)
 - Developer Documentation, Examples
 - Digital Signature support
 - Asynchronous Subscription support
 - Implements [Using WSDL in a UDDI Registry](https://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm)
 - Provides a UDDI v3 Technology Compatibility Kit (Java only)
 - Provides backwards compatibility with UDDIv2 endpoints using the v3 API Set (Java only)
 - Java based Command Line Interface client

## jUDDIv2 Services

 - UDDI version [2.0](https://www.oasis-open.org/standards#uddiv2) compliant
 - Supports for JDK 1.3.1 and later

## News

Feb 11, 2017, jUDDI Release 3.3.4

Sept 12, 2016, jUDDI Release 3.3.3

Nov 10, 2015 jUDDI Release 3.3.2

Oct 5, 2015 jUDDI Release 3.3.1

July 15, 2015 jUDDI Release 3.3.0

Dec 5, 2014 jUDDI Release 3.2.1

Feb 5, 2014 jUDDI Release 3.2.0, Migration from SVN to GIT

Jan, 2014 Happy New Year! Web site updated

May, 2013 jUDDI Release 3.1.5

Dec, 2012 Don't forget to check out the [jUDDI Blog](http://apachejuddi.blogspot.com/)

Mar, 2012 Scout Release 1.2.6

Nov, 2010 Release 3.0.4

Aug, 2010 jUDDI and Scout are promoted to Top Level Project named jUDDI

May, 2010 Release 3.0.2

Oct 26, 2009 Release 3.0.0

Aug 11, 2009 [Release 2.0](http://apachejuddi.blogspot.com/2009/07/release-juddi-v2-thank-you-steve-viens.html) and 2.0.1

June 5, 2009 Release 3.0.0.beta

May 31, 2009 Release 2.0rc7

Feb 13, 2009 Version 3.0.0.alpha is now available

Feb 10, 2009 Version 2.0rc6 is now available.

Dec 13, 2007 Version 2.0rc5 is now available.

June 7, 2005 Version 0.9rc4 is now available.

July 2, 2004 Version 0.9rc3 is now available.

June 29, 2004 Version 0.9rc2 is now available.

June 16, 2004 Version 0.9rc1 is now available.

March 24, 2004 jUDDI graduates from the Apache Incubator into Apache Web Services Project.

Oct 08, 2003 The Apache Software Foundation's Web Services PMC (http://ws.apache.org/) voted to accept jUDDI into the Apache Incubator. The move is expected to be complete in early December.

July 22, 2003 A proposal to contribute jUDDI to the Apache Software Foundation's Web Services Project is being considered.

July 22, 2003 Version 0.8.0 is now available.

June 27, 2003 Version 0.7.1 is now available.

April 22, 2003 Version 0.7.0 is now available.

## About UDDI

The Universal Description, Discovery and Integration (UDDI) protocol is one of the major building blocks required for successful Web services. UDDI creates a standard interoperable platform that enables companies and applications to quickly, easily, and dynamically find and use Web services over the Internet. UDDI also allows operational registries to be maintained for different purposes in different contexts. UDDI is a cross-industry effort driven by major platform and software providers, as well as marketplace operators and e-business leaders within the OASIS standards consortium.

Additional information regarding UDDI can be found at [uddi.xml.org](http://uddi.xml.org/).
